#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-5d724e6255914e391bee90b30a4cef13
key: yesod_5bJoiTvhFIQAYHKBSLRaoc
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
exposed-modules:
    Yesod.Default.Ignore
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-7.10.3/site-local/yesod-default-1.2.0
data-dir: /usr/share/arm-linux-ghc-7.10.3/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-5bJoiTvhFIQAYHKBSLRaoc
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    yesod-core-1.4.20.2-b3dddaeebe1e00a8ca9ebbc062ef002b
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
